==> zio-aws-route53_2.13-7.28.29.7-sources.jar: zio/aws/route53/model/ListHealthChecksResponse.scala <==
package zio.aws.route53.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.route53.model.primitives.{
  PageMaxItems,
  PageTruncated,
  PageMarker
}
import scala.jdk.CollectionConverters._
final case class ListHealthChecksResponse(
    healthChecks: Iterable[zio.aws.route53.model.HealthCheck],
    marker: PageMarker,
    isTruncated: PageTruncated,
    nextMarker: Optional[PageMarker] = Optional.Absent,
    maxItems: PageMaxItems
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.route53.model.ListHealthChecksResponse = {
    import ListHealthChecksResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.route53.model.ListHealthChecksResponse
      .builder()
      .healthChecks(healthChecks.map { item =>
        item.buildAwsValue()
      }.asJavaCollection)
      .marker(PageMarker.unwrap(marker): java.lang.String)
      .isTruncated(PageTruncated.unwrap(isTruncated): java.lang.Boolean)
      .optionallyWith(
        nextMarker.map(value => PageMarker.unwrap(value): java.lang.String)
      )(_.nextMarker)
      .maxItems(PageMaxItems.unwrap(maxItems): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.route53.model.ListHealthChecksResponse.ReadOnly =
    zio.aws.route53.model.ListHealthChecksResponse.wrap(buildAwsValue())
}
object ListHealthChecksResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.route53.model.ListHealthChecksResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.route53.model.ListHealthChecksResponse =
      zio.aws.route53.model.ListHealthChecksResponse(
        healthChecks.map { item =>
          item.asEditable
        },
        marker,
        isTruncated,
        nextMarker.map(value => value),
        maxItems
      )
    def healthChecks: List[zio.aws.route53.model.HealthCheck.ReadOnly]
    def marker: PageMarker
    def isTruncated: PageTruncated
    def nextMarker: Optional[PageMarker]
    def maxItems: PageMaxItems
    def getHealthChecks
        : ZIO[Any, Nothing, List[zio.aws.route53.model.HealthCheck.ReadOnly]] =
      ZIO.succeed(healthChecks)
    def getMarker: ZIO[Any, Nothing, PageMarker] = ZIO.succeed(marker)
    def getIsTruncated: ZIO[Any, Nothing, PageTruncated] =
      ZIO.succeed(isTruncated)
    def getNextMarker: ZIO[Any, AwsError, PageMarker] =
      AwsError.unwrapOptionField("nextMarker", nextMarker)
    def getMaxItems: ZIO[Any, Nothing, PageMaxItems] = ZIO.succeed(maxItems)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.route53.model.ListHealthChecksResponse
  ) extends zio.aws.route53.model.ListHealthChecksResponse.ReadOnly {
    override val healthChecks
        : List[zio.aws.route53.model.HealthCheck.ReadOnly] = impl
      .healthChecks()
      .asScala
      .map { item =>
        zio.aws.route53.model.HealthCheck.wrap(item)
      }
      .toList
    override val marker: PageMarker =
      zio.aws.route53.model.primitives.PageMarker(impl.marker())
    override val isTruncated: PageTruncated =
      zio.aws.route53.model.primitives.PageTruncated(impl.isTruncated())
    override val nextMarker: Optional[PageMarker] = zio.aws.core.internal
      .optionalFromNullable(impl.nextMarker())
      .map(value => zio.aws.route53.model.primitives.PageMarker(value))
    override val maxItems: PageMaxItems =
      zio.aws.route53.model.primitives.PageMaxItems(impl.maxItems())
  }
  def wrap(
      impl: software.amazon.awssdk.services.route53.model.ListHealthChecksResponse
  ): zio.aws.route53.model.ListHealthChecksResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-route53_3-5.17.116.1-sources.jar: zio/aws/route53/model/ListHealthChecksResponse.scala <==
package zio.aws.route53.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.route53.model.primitives.{
  PageMaxItems,
  PageTruncated,
  PageMarker
}
import scala.jdk.CollectionConverters.*
final case class ListHealthChecksResponse(
    healthChecks: Iterable[zio.aws.route53.model.HealthCheck],
    marker: PageMarker,
    isTruncated: PageTruncated,
    nextMarker: Option[PageMarker] = None,
    maxItems: PageMaxItems
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.route53.model.ListHealthChecksResponse = {
    import ListHealthChecksResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.route53.model.ListHealthChecksResponse
      .builder()
      .healthChecks(healthChecks.map { item =>
        item.buildAwsValue()
      }.asJavaCollection)
      .marker(PageMarker.unwrap(marker): java.lang.String)
      .isTruncated(PageTruncated.unwrap(isTruncated): java.lang.Boolean)
      .optionallyWith(
        nextMarker.map(value => PageMarker.unwrap(value): java.lang.String)
      )(_.nextMarker)
      .maxItems(PageMaxItems.unwrap(maxItems): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.route53.model.ListHealthChecksResponse.ReadOnly =
    zio.aws.route53.model.ListHealthChecksResponse.wrap(buildAwsValue())
}
object ListHealthChecksResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.route53.model.ListHealthChecksResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.route53.model.ListHealthChecksResponse =
      zio.aws.route53.model.ListHealthChecksResponse(
        healthChecks.map { item =>
          item.asEditable
        },
        marker,
        isTruncated,
        nextMarker.map(value => value),
        maxItems
      )
    def healthChecks: List[zio.aws.route53.model.HealthCheck.ReadOnly]
    def marker: PageMarker
    def isTruncated: PageTruncated
    def nextMarker: Option[PageMarker]
    def maxItems: PageMaxItems
    def getHealthChecks
        : ZIO[Any, Nothing, List[zio.aws.route53.model.HealthCheck.ReadOnly]] =
      ZIO.succeed(healthChecks)
    def getMarker: ZIO[Any, Nothing, PageMarker] = ZIO.succeed(marker)
    def getIsTruncated: ZIO[Any, Nothing, PageTruncated] =
      ZIO.succeed(isTruncated)
    def getNextMarker: ZIO[Any, AwsError, PageMarker] =
      AwsError.unwrapOptionField("nextMarker", nextMarker)
    def getMaxItems: ZIO[Any, Nothing, PageMaxItems] = ZIO.succeed(maxItems)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.route53.model.ListHealthChecksResponse
  ) extends zio.aws.route53.model.ListHealthChecksResponse.ReadOnly {
    override val healthChecks
        : List[zio.aws.route53.model.HealthCheck.ReadOnly] = impl
      .healthChecks()
      .asScala
      .map { item =>
        zio.aws.route53.model.HealthCheck.wrap(item)
      }
      .toList
    override val marker: PageMarker =
      zio.aws.route53.model.primitives.PageMarker(impl.marker())
    override val isTruncated: PageTruncated =
      zio.aws.route53.model.primitives.PageTruncated(impl.isTruncated())
    override val nextMarker: Option[PageMarker] = scala
      .Option(impl.nextMarker())
      .map(value => zio.aws.route53.model.primitives.PageMarker(value))
    override val maxItems: PageMaxItems =
      zio.aws.route53.model.primitives.PageMaxItems(impl.maxItems())
  }
  def wrap(
      impl: software.amazon.awssdk.services.route53.model.ListHealthChecksResponse
  ): zio.aws.route53.model.ListHealthChecksResponse.ReadOnly = new Wrapper(impl)
}
